/* fixed.c - compile with -lm option to link in maths library for sin() fn */
#include "math.h"

static FIXP g_SineTable[1024];

void fixInitialiseLibrary(void)
{
   ...

   for(i=0;i<1024;i++)
      {
      fSineValue = sin(M_PI * 2.0f * i / 1024.0f);
      g_SineTable[i] = FLOAT_TO_FIXED(fSineValue);
      }

}

FIXP fixSin(FIXP theta)
{
/* We need to scale theta from 0 to 2pi to 0 to 1023 */
/* i.e. offset = theta/2pi * 1024 */

/* Compute the scale as a float */
float scale = 1024.0f / (2.0f * M_PI);

/* Convert to our fixed-point notation */
FIXP fixed_scale = FLOAT_TO_FIXED(scale);

/* Find our genuine offset */
int offset = MTH_MUL(theta, fixed_scale);

/* Convert out fixed-point number into a 'normal' int */
offset >>= FIX_FRACBITS;

/* Sine is a cyclic function, so make sure an offset of 1024
   maps to 0, 1025 map to 1, and so on.
   (A table of 1024 elements was chosen to make masking easy) */
offset = offset & 1023;

/* Give our result back to the world */
return g_SineTable[offset];
}